@@ -122,16 +122,16 @@ compare_by_subtasks (GtdTask **t1,
 {
   GtdTask *task1, *task2;
 
-  if (!t1 && !t2)
-    return  0;
-  if (!t1)
-    return  1;
-  if (!t2)
-    return -1;
-
   task1 = *t1;
   task2 = *t2;
 
+  if (!task1 && !task2)
+    return  0;
+  if (!task1)
+    return  1;
+  if (!task2)
+    return -1;
+
   if (share_same_ancestor (task1, task2))
     {
       gint depth_difference;
@@ -290,12 +290,25 @@ real_remove_subtask (GtdTask *self,
   set_depth (subtask, 0);
 }
 
+static void
+task_list_weak_notified (gpointer  data,
+                         GObject  *where_the_object_was)
+{
+  GtdTask *task = GTD_TASK (data);
+  GtdTaskPrivate *priv = gtd_task_get_instance_private (task);
+  priv->list = NULL;
+}
+
 static void
 gtd_task_finalize (GObject *object)
 {
   GtdTask *self = (GtdTask*) object;
   GtdTaskPrivate *priv = gtd_task_get_instance_private (self);
 
+  if (priv->list)
+    g_object_weak_unref (G_OBJECT (priv->list), task_list_weak_notified, self);
+
+  priv->list = NULL;
   g_free (priv->description);
   g_object_unref (priv->component);
 
@@ -775,7 +788,7 @@ gtd_task_set_complete (GtdTask  *task,
           icaltimezone_convert_time (dt,
                                      NULL,
                                      icaltimezone_get_utc_timezone ());
-
+          g_date_time_unref (now);
         }
       else
         {
@@ -1076,11 +1089,15 @@ gtd_task_set_list (GtdTask     *task,
 
   priv = gtd_task_get_instance_private (task);
 
-  if (priv->list != list)
-    {
-      priv->list = list;
-      g_object_notify (G_OBJECT (task), "list");
-    }
+  if (priv->list == list)
+    return;
+
+  if (priv->list)
+    g_object_weak_unref (G_OBJECT (priv->list), task_list_weak_notified, task);
+
+  priv->list = list;
+  g_object_weak_ref (G_OBJECT (priv->list), task_list_weak_notified, task);
+  g_object_notify (G_OBJECT (task), "list");
 }
 
 /**
